define([
	"dojo/_base/declare",
	"dojo/when",
	"dojox/mvc/getPlainValue",
	"dojox/mvc/at",
	"dojox/mvc/getStateful",

	"aps/_View",
	"aps/ResourceStore",

	"./displayError",

	"dojo/text!./newvps.json"
], function (
	declare,
	when,
	getPlainValue,
	at,
	getStateful,

	_View,
	Store,

	displayError,

	newVPS
) {
	return declare(_View, {
		init: function () {
			/* Declare data sources */
			this.store = new Store({
				target: "/aps/2/resources"
			});
			aps.app.model.set("editVPS", getStateful(JSON.parse(newVPS)));

			/* Define and return widgets */
			return ["aps/Panel", {
					id: "edit_form"
				},
				[
					["aps/FieldSet", {
							id: "edit_general",
							title: "General"
						},
						[
							["aps/TextBox", {
								id: "edit_serverName",
								label: _("Server Name"),
								value: at(aps.app.model.editVPS, "name"),
								required: true
							}],
							["aps/TextBox", {
								id: "edit_description",
								label: _("Description"),
								value: at(aps.app.model.editVPS, "description")
							}]
						]
					],
					["aps/FieldSet", {
							id: "edit_props",
							title: "Server Configuration"
						},
						[
							["aps/Spinner", {
								id: "edit_cpu",
								label: _( "CPU Number"),
								minimum: 1,
								maximum: 16,
								value: at(aps.app.model.editVPS.hardware.CPU, "number"),
								step: 1
							}],
							["aps/Spinner", {
								id: "edit_disk",
								label: _("Disk Space"),
								minimum: 1,
								maximum: 100,
								value: at(aps.app.model.editVPS.hardware, "diskspace"),
								legend: _("Gb"),
								step: 1
							}],
							["aps/Spinner", {
								id: "edit_ram",
								label: _("RAM"),
								minimum: 128,
								maximum: 8192,
								value: at(aps.app.model.editVPS.hardware, "memory"),
								legend: _("Mb"),
								step: 128
							}]
						]
					]
				]
			];

		},    // End of Init

		/* Create handlers for the navigation buttons */
		onCancel: function() {
			aps.apsc.gotoView("servers");
		},
		onSubmit: function() {
			var form = this.byId("edit_form");
			if (!form.validate()) {
				aps.apsc.cancelProcessing();
				return;
			}
			when(this.store.put(getPlainValue(aps.app.model.editVPS)),
				function() {
					aps.apsc.gotoView("servers");
				},
				displayError
			);
		},

		onContext: function() {
			/* Getting VPS properties */
			this.store.get(aps.context.vars.vps.aps.id).then(function(vps) {
				/* Collect the VPS properties in the model */
				aps.app.model.set("editVPS", getStateful(vps));
				aps.apsc.hideLoading(); // Mandatory call
			});
		},

		onHide: function() {
			/* Reset widget fields to avoid flickering when opening another VPS */
			aps.app.model.set("editVPS", getStateful(JSON.parse(newVPS)));
		}

	});    // End of Declare
});        // End of Define
