define([
	"dojo/_base/declare",
	"dojox/mvc/getPlainValue",
	"dojox/mvc/at",
	"dojox/mvc/getStateful",

	"aps/_View",
	"aps/load",
	"aps/Memory",
	/* Include JSON file that defines the default properties */
	"dojo/text!./newvps.json"
	],
	function (
	declare,
	getPlainValue,
	at,
	getStateful,

	_View,
	load,
	Memory,

	newVPS
	) {
		return declare(_View, {
			init: function() {
				/* Declare the data sources */
				var oses = new Memory({
					idProperty: "value",
					data: [
						{ value: "centos6",      label: "CentOS 6" },
						{ value: "debian",       label: "Debian" },
						{ value: "windows2008",  label: "Windows 2008 Server" },
						{ value: "windows2012",  label: "Windows 2012 Server" }
					]
				});
				aps.app.model.set("newVPS", getStateful(JSON.parse(newVPS)));

				/* Define and return widgets */
				return ["aps/Panel", {
					id: "srvNew1_form"
				}, [
					["aps/FieldSet", {
							title: "General"
						},
						[
							["aps/TextBox", {
								id: "srvNew1_serverName",
								label: _("Server Name"),
								value: at(aps.app.model.newVPS, "name"),
								required: true
							}],
							["aps/TextBox", {
								id: "srvNew1_description",
								label: _("Description"),
								value: at(aps.app.model.newVPS, "description")}]
						]
					],
					["aps/FieldSet", {
							id: "srvNew1_",
							title: "Server Configuration"
						},
						[
							["aps/Select", {
								id: "srvNew1_os",
								label: _( "OS"),
								value: at(aps.app.model.newVPS.platform.OS, "name"),
								store: oses
							}],
							["aps/Spinner", {
								id: "srvNew1_cpu",
								label: _( "CPU Number"),
								minimum: 1,
								maximum: 16,
								value: at(aps.app.model.newVPS.hardware.CPU, "number"),
								step: 1
							}],
							["aps/Spinner", {
								id: "srvNew1_disk",
								label: _("Disk Space"),
								minimum: 1,
								maximum: 100,
								value: at(aps.app.model.newVPS.hardware, "diskspace"),
								legend: _("Gb"),
								step: 1
							}],
							["aps/Spinner", {
								id: "srvNew1_ram",
								label: _("RAM"),
								minimum: 128,
								maximum: 8192,
								value: at(aps.app.model.newVPS.hardware, "memory"),
								legend: _("Mb"),
								step: 128
							}]
						]
					]
				]];

			},    // End of Init

			/* Create handlers for the navigation buttons */

			onCancel: function() {
				aps.apsc.gotoView("servers");
			},

			onNext: function() {
				var form = this.byId("srvNew1_form");

				/* Validate the values assigned to widgets */
				if (!form.validate()) {
					aps.apsc.cancelProcessing();
					return;
				}

				/* Proceed to the next screen */
				aps.apsc.gotoView("server-new-last");
			},

			onShow: function() {
				if (aps.app.isNew !== false)
					aps.app.model.set("newVPS", JSON.parse(newVPS));
			},

			onHide: function() {
				delete aps.app.isNew;
			}
		});    // End of Declare
	});        // End of Define
