define([
    "dojo/_base/declare",
    "dojo/when",
    "dojox/mvc/getStateful",
    "dojox/mvc/getPlainValue",
    "dojox/mvc/at",

    "aps/_View",
    "aps/ResourceStore",
    "aps/Memory",

    "./displayError"
], function (
    declare,
    when,
    getStateful,
    getPlainValue,
    at,

    _View,
    Store,
    Memory,

    displayError
) {
    return declare(_View, {
        init: function() {

            /* Create widgets */
            return ["aps/Panel", {
                    id: "srvNew_page"
                },
                [
                    ["aps/FieldSet", {
                        id: "srvNew_general",
                        title: "General"
                    },
                    [
                        ["aps/Output", {
                            id: "srvNew_serverName",
                            label: "Server Name",
                            value: at(aps.app.model.newVPS, "name")
                        }],
                        ["aps/Output", {
                            id: "srvNew_description",
                            label: "Description",
                            value: at(aps.app.model.newVPS, "description")
                        }]
                    ]],
                    ["aps/FieldSet", {
                        id: "srvNew_props",
                        title: "Server Configuration"
                    },
                    [
                        ["aps/Output", {
                            id: "srvNew_os",
                            label: "OS",
                            value: at(aps.app.model.newVPS.platform.OS, "name")
                        }],
                        ["aps/Output", {
                            id: "srvNew_cpu",
                            label: "CPU",
                            value: at(aps.app.model.newVPS.hardware.CPU, "number")
                        }],
                        ["aps/Output", {
                            id: "srvNew_disk",
                            label: "Disk Space",
                            value: at(aps.app.model.newVPS.hardware, "diskspace")
                        }],
                        ["aps/Output", {
                            id: "srvNew_ram",
                            label: "RAM",
                            value: at(aps.app.model.newVPS.hardware, "memory")
                        }]
                    ]]
                ]
            ];
        },	// End of Init

        /* Create handlers for the navigation buttons */
        onSubmit: function() {
            aps.context.subscriptionId = aps.context.vars.context.aps.subscription;
            var page = this.byId("srvNew_page");
            if (!page.validate()) {
                aps.apsc.cancelProcessing();
                return;
            }
            /* Declare data sources */
            var store = new Store({
                apsType: "http://aps-standard.org/samples/basic1p/vps/1.0",
                target: "/aps/2/resources/" + aps.context.vars.context.aps.id + "/vpses"
            });
            when(store.put(getPlainValue(aps.app.model.newVPS)),
                function() {
                    aps.apsc.gotoView("servers");
                },
                displayError
            );
        },

        onPrev: function() {
            aps.app.isNew = false;
            aps.apsc.gotoView("server-new-1");
        }
    });	// End of Declare
});		// End of Define
